.. image:: https://raw.githubusercontent.com/ClearcodeHQ/matchbox/master/logo.png
    :width: 100px
    :height: 150px

matchbox
========

.. image:: https://img.shields.io/pypi/v/matchbox.svg
    :target: https://pypi.python.org/pypi/matchbox/
    :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/matchbox/badge/?version=v1.0.0
    :target: http://matchbox.readthedocs.org/en/v1.0.0/
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/wheel/matchbox.svg
    :target: https://pypi.python.org/pypi/matchbox/
    :alt: Wheel Status

.. image:: https://img.shields.io/pypi/pyversions/matchbox.svg
    :target: https://pypi.python.org/pypi/matchbox/
    :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/matchbox.svg
    :target: https://pypi.python.org/pypi/matchbox/
    :alt: License

Package status
--------------

.. image:: https://travis-ci.org/ClearcodeHQ/matchbox.svg?branch=v1.0.0
    :target: https://travis-ci.org/ClearcodeHQ/matchbox
    :alt: Tests

.. image:: https://coveralls.io/repos/ClearcodeHQ/matchbox/badge.png?branch=v1.0.0
    :target: https://coveralls.io/r/ClearcodeHQ/matchbox?branch=v1.0.0
    :alt: Coverage Status

Matchbox is a simple python library designed to make selecting object, or object's set based on
    required characteristics quick operation. No iterating, and no value checking on actual objects,
    just select and operations on dictionaries.


Package resources
-----------------

* Bug tracker: https://github.com/ClearcodeHQ/matchbox/issues
* Documentation: http://matchbox.readthedocs.org/
* Benchmarks: http://clearcodehq.github.io/matchbox/

